@@ -31,3 +31,6 @@ EVE_GROUP_ID_MOON = 8
 EVE_GROUP_ID_ASTEROID_BELT = 9
 EVE_GROUP_ID_STARGATE = 10
 EVE_GROUP_ID_STATION = 15
+
+# ESI
+POST_UNIVERSE_NAMES_MAX_ITEMS = 1000
