@@ -1038,7 +1038,7 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         self.assertEqual(result.distance, 1000)
 
 
-@override_settings(CELERY_ALWAYS_EAGER=True)
+@override_settings(CELERY_ALWAYS_EAGER=True, CELERY_EAGER_PROPAGATES_EXCEPTIONS=True)
 @patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_GRAPHICS", False)
 @patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_DOGMAS", False)
 @patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_MARKET_GROUPS", False)
